@@ -16,6 +16,7 @@ import sys
 from .packet import ApiPacketBody
 from .packet import ApiRequestPacket
 from .packet import ApiResponsePacket
+from .packet import parse_api_body
 from ..on_demand_action import OnDemandAction
 
 
@@ -107,7 +108,7 @@ class OnDemandApi(OnDemandAction):
         self.__output_stream = output_stream
 
         packet = ApiRequestPacket()
-        packet.read(self.__input_stream)
+        packet.read(self.__input_stream, parse_api_body)
 
         if packet.is_init():
             try:
