@@ -13,9 +13,10 @@ limitations under the License.
 
 import os
 import logging
+from logging.handlers import RotatingFileHandler
 
 
-def config_logging(level=None, filename=None):
+def config_logging(level=None, filename=None, max_bytes=1024*1024*20, backup_count=5):
     if filename is None:
         log_dir = '../log'
         if not os.path.exists(log_dir):
@@ -28,7 +29,9 @@ def config_logging(level=None, filename=None):
     if level is None:
         level = 'INFO'
 
-    logging.basicConfig(filename=filename,
-                        level=level,
+    handler = RotatingFileHandler(filename, maxBytes=max_bytes, backupCount=backup_count)
+
+    logging.basicConfig(level=level,
+                        handlers=[handler],
                         format="%(asctime)s %(name)s %(levelname)s %(message)s",
                         datefmt='%Y-%m-%d  %H:%M:%S %a')
